# Creating your event

It would be useful to have the [JS functions Documentation](devNotes/usefulJSFunctionDocumentation.txt) open and in particular the "Core Slave Functions" section.

First decide your events name (e.g. `MyEvent`)

```js
App.Events.MyEvent = class MyEvent extends App.Events.BaseEvent {
 // The event only fires if the optional conditions listed in this array are met. This can be empty.
 eventPrerequisites() {
   // Conditional example
   return [
    () => V.plot === 1
   ];

   // empty example
   return [];
 }

 // Each position in the array correlates to conditions that a slave must meet to be selected. This can also be empty.
 actorPrerequisites() {
  // Single slave example
  return [
   [
    s => canWalk(s),
    s => s.fetish !== Fetish.MINDBROKEN,
    s => s.devotion >= 50,
    s => s.trust <= 20
   ]
  ];

  // Dual slave
  return [
   [ // first actor
    s => canWalk(s),
    s => s.fetish !== Fetish.MINDBROKEN,
    s => s.devotion >= 50,
    s => s.trust <= 20
   ],
   [ // second actor
    s => s.ID === getSlave(this.actors[0]).mother
   ]
  ];

  // One actor, but any slave will do
  return [[]];

  // Empty (no actors at all)
  return [];
 }

 execute(node) {
  /** @type {Array<App.Entity.SlaveState>} */
  let [eventSlave] = this.actors.map(a => getSlave(a));
  const {
   He, he, His, his, him, himself
  } = getPronouns(eventSlave);
  const {
   HeU, heU, hisU, himU, himselfU
  } = getNonlocalPronouns(V.seeDicks).appendSuffix('U');

  // show slave art
  App.Events.drawEventArt(node, eventSlave, "no clothing");

  let t = [];

  t.push(`Event info text goes here`)

  App.Events.addParagraph(node, t);

  // Event branches
  App.Events.addResponses(node, [
   new App.Events.Result(`Text shown to user`, choiceA),
   ...
  ]);

  function choiceA() {
   t = [];

   t.push(`choice text goes here`);

   // additional code if needed

   // effects on the actors
   eventSlave.devotion += 4;
   eventSlave.trust += 4;
   return t;
  }
 }
};
```

## Dealing with lisping

Use `getEnunciation()` and `Spoken()` when dealing with slave dialog. For example:

```js
const {say, title: Master} = getEnunciation(eventSlave);

return `"${Spoken(`Some text, ${Master},`)}" says ${eventSlave.slaveName}.`;
```

## Adding your event to the pool

Now that your event has been created, it needs to be added to the pool of possible events for its type.
For most events, as well as for our example, this is in Random Individual Event.
This pool can be found at `src/events/randomEvent.js`.
Simply add your event to the array in `App.Events.getIndividualEvents`.

## Testing

In the Options menu, open the "Debug & cheating" tab and enable CheatMode.
Once you get to "Random Individual Event" select any slave and at the bottom under DEBUG: there should be
 a input box with "Check Prerequisites and Casting" link next to it.
Per the example under it, place your event's full name into it e.g. App.Events.myEvent and then hit said link.
If everything works as intended you should see output

## Examples

### Single slave

- [src/events/RESS/devotedFearfulSlave.js](src/events/RESS/devotedFearfulSlave.js)

### Dual slave

- [src/events/reDevotedTwins.js](src/events/reDevotedTwins.js)
